bact-archiver package
=====================

The module :mod:`bact_archiver` provides access to an EPICS appliance
archiver using the protocol buffer interface.


.. toctree::

    bact_archiver_usage
    bact_archiver_build
    bact_archiver_config
    bact_archiver_register
    bact_archiver.archiver

Module contents
---------------

.. automodule:: bact_archiver
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::
